import { jsx as _jsx } from "react/jsx-runtime";
import { formatKeyboardShortcut, } from "@blocknote/core";
import { useMemo, useState } from "react";
import { RiBold, RiCodeFill, RiItalic, RiStrikethrough, RiUnderline, } from "react-icons/ri";
import { useBlockNoteEditor } from "../../../../hooks/useBlockNoteEditor";
import { useEditorContentOrSelectionChange } from "../../../../hooks/useEditorContentOrSelectionChange";
import { useSelectedBlocks } from "../../../../hooks/useSelectedBlocks";
import { ToolbarButton } from "../../../mantine-shared/Toolbar/ToolbarButton";
const icons = {
    bold: RiBold,
    italic: RiItalic,
    underline: RiUnderline,
    strike: RiStrikethrough,
    code: RiCodeFill,
};
const shortcuts = {
    bold: "Mod+B",
    italic: "Mod+I",
    underline: "Mod+U",
    strike: "Mod+Shift+X",
    code: "",
};
function checkBasicTextStyleInSchema(style, editor) {
    return (style in editor.schema.styleSchema &&
        editor.schema.styleSchema[style].type === style &&
        editor.schema.styleSchema[style].propSchema === "boolean");
}
export const BasicTextStyleButton = (props) => {
    const editor = useBlockNoteEditor();
    const basicTextStyleInSchema = checkBasicTextStyleInSchema(props.basicTextStyle, editor);
    const selectedBlocks = useSelectedBlocks(editor);
    const [active, setActive] = useState(props.basicTextStyle in editor.getActiveStyles());
    useEditorContentOrSelectionChange(() => {
        if (basicTextStyleInSchema) {
            setActive(props.basicTextStyle in editor.getActiveStyles());
        }
    }, editor);
    const toggleStyle = (style) => {
        if (!basicTextStyleInSchema) {
            return;
        }
        editor.focus();
        if (editor.schema.styleSchema[style].propSchema !== "boolean") {
            throw new Error("can only toggle boolean styles");
        }
        editor.toggleStyles({ [style]: true });
    };
    const show = useMemo(() => {
        if (!basicTextStyleInSchema) {
            return false;
        }
        // Also don't show when none of the selected blocks have text content
        return !!selectedBlocks.find((block) => block.content !== undefined);
    }, [basicTextStyleInSchema, selectedBlocks]);
    if (!show) {
        return null;
    }
    return (_jsx(ToolbarButton, { onClick: () => toggleStyle(props.basicTextStyle), isSelected: active, mainTooltip: props.basicTextStyle.slice(0, 1).toUpperCase() +
            props.basicTextStyle.slice(1), secondaryTooltip: formatKeyboardShortcut(shortcuts[props.basicTextStyle]), icon: icons[props.basicTextStyle] }));
};
//# sourceMappingURL=BasicTextStyleButton.js.map