import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Menu } from "@mantine/core";
import { useCallback, useMemo, useState } from "react";
import { useBlockNoteEditor } from "../../../../hooks/useBlockNoteEditor";
import { useEditorContentOrSelectionChange } from "../../../../hooks/useEditorContentOrSelectionChange";
import { usePreventMenuOverflow } from "../../../../hooks/usePreventMenuOverflow";
import { useSelectedBlocks } from "../../../../hooks/useSelectedBlocks";
import { ColorIcon } from "../../../mantine-shared/ColorPicker/ColorIcon";
import { ColorPicker } from "../../../mantine-shared/ColorPicker/ColorPicker";
import { ToolbarButton } from "../../../mantine-shared/Toolbar/ToolbarButton";
function checkColorInSchema(color, editor) {
    return (`${color}Color` in editor.schema.styleSchema &&
        editor.schema.styleSchema[`${color}Color`].type === `${color}Color` &&
        editor.schema.styleSchema[`${color}Color`].propSchema === "string");
}
export const ColorStyleButton = () => {
    const editor = useBlockNoteEditor();
    const textColorInSchema = checkColorInSchema("text", editor);
    const backgroundColorInSchema = checkColorInSchema("background", editor);
    const selectedBlocks = useSelectedBlocks(editor);
    const [currentTextColor, setCurrentTextColor] = useState(textColorInSchema
        ? editor.getActiveStyles().textColor || "default"
        : "default");
    const [currentBackgroundColor, setCurrentBackgroundColor] = useState(backgroundColorInSchema
        ? editor.getActiveStyles().backgroundColor || "default"
        : "default");
    useEditorContentOrSelectionChange(() => {
        if (textColorInSchema) {
            setCurrentTextColor(editor.getActiveStyles().textColor || "default");
        }
        if (backgroundColorInSchema) {
            setCurrentBackgroundColor(editor.getActiveStyles().backgroundColor || "default");
        }
    }, editor);
    const { ref, updateMaxHeight } = usePreventMenuOverflow();
    const setTextColor = useCallback((color) => {
        if (!textColorInSchema) {
            throw Error("Tried to set text color, but style does not exist in editor schema.");
        }
        editor.focus();
        color === "default"
            ? editor.removeStyles({ textColor: color })
            : editor.addStyles({ textColor: color });
    }, [editor, textColorInSchema]);
    const setBackgroundColor = useCallback((color) => {
        if (!backgroundColorInSchema) {
            throw Error("Tried to set background color, but style does not exist in editor schema.");
        }
        editor.focus();
        color === "default"
            ? editor.removeStyles({ backgroundColor: color })
            : editor.addStyles({ backgroundColor: color });
    }, [backgroundColorInSchema, editor]);
    const show = useMemo(() => {
        if (!textColorInSchema && !backgroundColorInSchema) {
            return false;
        }
        for (const block of selectedBlocks) {
            if (block.content !== undefined) {
                return true;
            }
        }
        return false;
    }, [backgroundColorInSchema, selectedBlocks, textColorInSchema]);
    if (!show) {
        return null;
    }
    return (_jsxs(Menu, { withinPortal: false, onOpen: updateMaxHeight, children: [_jsx(Menu.Target, { children: _jsx(ToolbarButton, { mainTooltip: "Colors", icon: () => (_jsx(ColorIcon, { textColor: currentTextColor, backgroundColor: currentBackgroundColor, size: 20 })) }) }), _jsx("div", { ref: ref, children: _jsx(Menu.Dropdown, { children: _jsx(ColorPicker, { text: textColorInSchema
                            ? {
                                color: currentTextColor,
                                setColor: setTextColor,
                            }
                            : undefined, background: backgroundColorInSchema
                            ? {
                                color: currentBackgroundColor,
                                setColor: setBackgroundColor,
                            }
                            : undefined }) }) })] }));
};
//# sourceMappingURL=ColorStyleButton.js.map