import { jsx as _jsx } from "react/jsx-runtime";
import { useCallback, useMemo, useState } from "react";
import { RiLink } from "react-icons/ri";
import { formatKeyboardShortcut, } from "@blocknote/core";
import { useBlockNoteEditor } from "../../../../hooks/useBlockNoteEditor";
import { useEditorContentOrSelectionChange } from "../../../../hooks/useEditorContentOrSelectionChange";
import { useSelectedBlocks } from "../../../../hooks/useSelectedBlocks";
import { ToolbarButton } from "../../../mantine-shared/Toolbar/ToolbarButton";
import { ToolbarInputsMenu } from "../../../mantine-shared/Toolbar/ToolbarInputsMenu";
import { EditLinkMenuItems } from "../../../LinkToolbar/mantine/EditLinkMenuItems";
function checkLinkInSchema(editor) {
    return ("link" in editor.schema.inlineContentSchema &&
        editor.schema.inlineContentSchema["link"] === "link");
}
export const CreateLinkButton = () => {
    const editor = useBlockNoteEditor();
    const linkInSchema = checkLinkInSchema(editor);
    const selectedBlocks = useSelectedBlocks(editor);
    const [url, setUrl] = useState(editor.getSelectedLinkUrl() || "");
    const [text, setText] = useState(editor.getSelectedText());
    useEditorContentOrSelectionChange(() => {
        setText(editor.getSelectedText() || "");
        setUrl(editor.getSelectedLinkUrl() || "");
    }, editor);
    const update = useCallback((url, text) => {
        editor.createLink(url, text);
        editor.focus();
    }, [editor]);
    const show = useMemo(() => {
        if (!linkInSchema) {
            return false;
        }
        for (const block of selectedBlocks) {
            if (block.content === undefined) {
                return false;
            }
        }
        return true;
    }, [linkInSchema, selectedBlocks]);
    if (!show) {
        return null;
    }
    return (_jsx(ToolbarInputsMenu, { button: _jsx(ToolbarButton, { mainTooltip: "Create Link", secondaryTooltip: formatKeyboardShortcut("Mod+K"), icon: RiLink }), dropdownItems: _jsx(EditLinkMenuItems, { url: url, text: text, editLink: update }) }));
};
//# sourceMappingURL=CreateLinkButton.js.map