import { jsx as _jsx } from "react/jsx-runtime";
import { checkBlockHasDefaultProp, checkBlockTypeHasDefaultProp, } from "@blocknote/core";
import { useCallback, useMemo } from "react";
import { RiAlignCenter, RiAlignJustify, RiAlignLeft, RiAlignRight, } from "react-icons/ri";
import { useBlockNoteEditor } from "../../../../hooks/useBlockNoteEditor";
import { useSelectedBlocks } from "../../../../hooks/useSelectedBlocks";
import { ToolbarButton } from "../../../mantine-shared/Toolbar/ToolbarButton";
const icons = {
    left: RiAlignLeft,
    center: RiAlignCenter,
    right: RiAlignRight,
    justify: RiAlignJustify,
};
export const TextAlignButton = (props) => {
    const editor = useBlockNoteEditor();
    const selectedBlocks = useSelectedBlocks(editor);
    const textAlignment = useMemo(() => {
        const block = selectedBlocks[0];
        if (checkBlockHasDefaultProp("textAlignment", block, editor)) {
            return block.props.textAlignment;
        }
        return;
    }, [editor, selectedBlocks]);
    const setTextAlignment = useCallback((textAlignment) => {
        editor.focus();
        for (const block of selectedBlocks) {
            if (checkBlockTypeHasDefaultProp("textAlignment", block.type, editor)) {
                editor.updateBlock(block, {
                    props: { textAlignment: textAlignment },
                });
            }
        }
    }, [editor, selectedBlocks]);
    const show = useMemo(() => {
        return !!selectedBlocks.find((block) => "textAlignment" in block.props);
    }, [selectedBlocks]);
    if (!show) {
        return null;
    }
    return (_jsx(ToolbarButton, { onClick: () => setTextAlignment(props.textAlignment), isSelected: textAlignment === props.textAlignment, mainTooltip: props.textAlignment === "justify"
            ? "Justify Text"
            : "Align Text " +
                props.textAlignment.slice(0, 1).toUpperCase() +
                props.textAlignment.slice(1), icon: icons[props.textAlignment] }));
};
//# sourceMappingURL=TextAlignButton.js.map