import { jsx as _jsx } from "react/jsx-runtime";
import { checkDefaultBlockTypeInSchema, } from "@blocknote/core";
import { useMemo, useState } from "react";
import { RiH1, RiH2, RiH3, RiListOrdered, RiListUnordered, RiText, } from "react-icons/ri";
import { useBlockNoteEditor } from "../../../../hooks/useBlockNoteEditor";
import { useEditorContentOrSelectionChange } from "../../../../hooks/useEditorContentOrSelectionChange";
import { useSelectedBlocks } from "../../../../hooks/useSelectedBlocks";
import { ToolbarSelect } from "../../../mantine-shared/Toolbar/ToolbarSelect";
export const blockTypeSelectItems = [
    {
        name: "Paragraph",
        type: "paragraph",
        icon: RiText,
        isSelected: (block) => block.type === "paragraph",
    },
    {
        name: "Heading 1",
        type: "heading",
        props: { level: 1 },
        icon: RiH1,
        isSelected: (block) => block.type === "heading" &&
            "level" in block.props &&
            block.props.level === 1,
    },
    {
        name: "Heading 2",
        type: "heading",
        props: { level: 2 },
        icon: RiH2,
        isSelected: (block) => block.type === "heading" &&
            "level" in block.props &&
            block.props.level === 2,
    },
    {
        name: "Heading 3",
        type: "heading",
        props: { level: 3 },
        icon: RiH3,
        isSelected: (block) => block.type === "heading" &&
            "level" in block.props &&
            block.props.level === 3,
    },
    {
        name: "Bullet List",
        type: "bulletListItem",
        icon: RiListUnordered,
        isSelected: (block) => block.type === "bulletListItem",
    },
    {
        name: "Numbered List",
        type: "numberedListItem",
        icon: RiListOrdered,
        isSelected: (block) => block.type === "numberedListItem",
    },
];
export const BlockTypeSelect = (props) => {
    const editor = useBlockNoteEditor();
    const selectedBlocks = useSelectedBlocks(editor);
    const [block, setBlock] = useState(editor.getTextCursorPosition().block);
    const filteredItems = useMemo(() => {
        return (props.items || blockTypeSelectItems).filter((item) => checkDefaultBlockTypeInSchema(item.type, editor));
    }, [editor, props.items]);
    const shouldShow = useMemo(() => filteredItems.find((item) => item.type === block.type) !== undefined, [block.type, filteredItems]);
    const fullItems = useMemo(() => {
        const onClick = (item) => {
            editor.focus();
            for (const block of selectedBlocks) {
                editor.updateBlock(block, {
                    type: item.type,
                    props: item.props,
                });
            }
        };
        return filteredItems.map((item) => ({
            text: item.name,
            icon: item.icon,
            onClick: () => onClick(item),
            isSelected: item.isSelected(block),
        }));
    }, [block, filteredItems, editor, selectedBlocks]);
    useEditorContentOrSelectionChange(() => {
        setBlock(editor.getTextCursorPosition().block);
    }, editor);
    if (!shouldShow) {
        return null;
    }
    return _jsx(ToolbarSelect, { items: fullItems });
};
//# sourceMappingURL=BlockTypeSelect.js.map