import { jsx as _jsx } from "react/jsx-runtime";
import { filterSuggestionItems, } from "@blocknote/core";
import { flip, offset, size } from "@floating-ui/react";
import { useBlockNoteEditor } from "../../hooks/useBlockNoteEditor";
import { useUIElementPositioning } from "../../hooks/useUIElementPositioning";
import { useUIPluginState } from "../../hooks/useUIPluginState";
import { SuggestionMenuWrapper } from "./SuggestionMenuWrapper";
import { getDefaultReactSlashMenuItems } from "./getDefaultReactSlashMenuItems";
import { SuggestionMenu } from "./mantine/SuggestionMenu";
export function SuggestionMenuController(props) {
    const editor = useBlockNoteEditor();
    const { triggerCharacter, suggestionMenuComponent } = props;
    let { onItemClick, getItems } = props;
    if (!onItemClick) {
        onItemClick = (item) => {
            item.onItemClick(editor);
        };
    }
    const callbacks = {
        closeMenu: editor.suggestionMenus.closeMenu,
        clearQuery: editor.suggestionMenus.clearQuery,
    };
    const state = useUIPluginState((callback) => editor.suggestionMenus.onUpdate.bind(editor.suggestionMenus)(triggerCharacter, callback));
    const { isMounted, ref, style } = useUIElementPositioning(state?.show || false, state?.referencePos || null, 2000, {
        placement: "bottom-start",
        middleware: [
            offset(10),
            // Flips the menu placement to maximize the space available, and prevents
            // the menu from being cut off by the confines of the screen.
            flip(),
            size({
                apply({ availableHeight, elements }) {
                    Object.assign(elements.floating.style, {
                        maxHeight: `${availableHeight - 10}px`,
                    });
                },
            }),
        ],
    });
    if (!isMounted || !state) {
        return null;
    }
    if (!getItems) {
        getItems = (async (query) => filterSuggestionItems(getDefaultReactSlashMenuItems(editor), query));
    }
    return (_jsx("div", { ref: ref, style: style, children: _jsx(SuggestionMenuWrapper, { query: state.query, closeMenu: callbacks.closeMenu, clearQuery: callbacks.clearQuery, getItems: getItems, suggestionMenuComponent: suggestionMenuComponent || SuggestionMenu, onItemClick: onItemClick }) }));
}
//# sourceMappingURL=SuggestionMenuController.js.map