import { createElement as _createElement } from "react";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Loader, Menu } from "@mantine/core";
import { Children, useMemo } from "react";
import { SuggestionMenuItem } from "./SuggestionMenuItem";
export function SuggestionMenu(props) {
    const { items, loadingState, selectedIndex, onItemClick } = props;
    const loader = loadingState === "loading-initial" || loadingState === "loading" ? (_jsx(Loader, { className: "bn-slash-menu-loader", type: "dots" })) : null;
    const renderedItems = useMemo(() => {
        let currentGroup = undefined;
        const renderedItems = [];
        for (let i = 0; i < items.length; i++) {
            const item = items[i];
            if (item.group !== currentGroup) {
                currentGroup = item.group;
                renderedItems.push(_jsx(Menu.Label, { children: currentGroup }, currentGroup));
            }
            renderedItems.push(_createElement(SuggestionMenuItem, { ...item, isSelected: i === selectedIndex, key: item.title, onClick: () => onItemClick?.(item) }));
        }
        return renderedItems;
    }, [items, selectedIndex, onItemClick]);
    return (_jsx(Menu, { withinPortal: false, trapFocus: false, 
        /** Hacky fix to get the desired menu behaviour. The trigger="hover"
         * attribute allows focus to remain on the editor, allowing for suggestion
         * filtering. The closeDelay=10000000 attribute allows the menu to stay open
         * practically indefinitely, as normally hovering off it would cause it to
         * close due to trigger="hover".
         */
        defaultOpened: true, trigger: "hover", closeDelay: 10000000, children: _jsxs(Menu.Dropdown, { onMouseDown: (event) => event.preventDefault(), className: "bn-slash-menu", children: [renderedItems, Children.count(renderedItems) === 0 &&
                    (props.loadingState === "loading" ||
                        props.loadingState === "loaded") && (_jsx(Menu.Item, { children: "No match found" })), loader] }) }));
}
//# sourceMappingURL=SuggestionMenu.js.map