import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { useState } from "react";
import { useBlockNoteEditor } from "../../hooks/useBlockNoteEditor";
import { useUIPluginState } from "../../hooks/useUIPluginState";
import { useTableHandlesPositioning } from "./hooks/useTableHandlesPositioning";
import { TableHandle } from "./mantine/TableHandle";
export const TableHandlesController = (props) => {
    const editor = useBlockNoteEditor();
    if (!editor.tableHandles) {
        throw new Error("TableHandlesController can only be used when BlockNote editor schema contains table block");
    }
    const callbacks = {
        rowDragStart: editor.tableHandles.rowDragStart,
        colDragStart: editor.tableHandles.colDragStart,
        dragEnd: editor.tableHandles.dragEnd,
        freezeHandles: editor.tableHandles.freezeHandles,
        unfreezeHandles: editor.tableHandles.unfreezeHandles,
    };
    const state = useUIPluginState(editor.tableHandles.onUpdate.bind(editor.tableHandles));
    const { rowHandle, colHandle } = useTableHandlesPositioning(state?.show || false, state?.referencePosCell || null, state?.referencePosTable || null, state?.draggingState
        ? {
            draggedCellOrientation: state?.draggingState?.draggedCellOrientation,
            mousePos: state?.draggingState?.mousePos,
        }
        : undefined);
    const [hideRow, setHideRow] = useState(false);
    const [hideCol, setHideCol] = useState(false);
    if (!rowHandle.isMounted || !colHandle.isMounted || !state) {
        return null;
    }
    const Component = props.tableHandle || TableHandle;
    return (_jsxs(_Fragment, { children: [!hideRow && (_jsx("div", { ref: rowHandle.ref, style: rowHandle.style, children: _jsx(Component
                // This "as any" unfortunately seems complicated to fix
                , { 
                    // This "as any" unfortunately seems complicated to fix
                    editor: editor, orientation: "row", showOtherSide: () => setHideCol(false), hideOtherSide: () => setHideCol(true), index: state.rowIndex, block: state.block, dragStart: callbacks.rowDragStart, dragEnd: callbacks.dragEnd, freezeHandles: callbacks.freezeHandles, unfreezeHandles: callbacks.unfreezeHandles }) })), !hideCol && (_jsx("div", { ref: colHandle.ref, style: colHandle.style, children: _jsx(Component, { editor: editor, orientation: "column", showOtherSide: () => setHideRow(false), hideOtherSide: () => setHideRow(true), index: state.colIndex, block: state.block, dragStart: callbacks.colDragStart, dragEnd: callbacks.dragEnd, freezeHandles: callbacks.freezeHandles, unfreezeHandles: callbacks.unfreezeHandles }) }))] }));
};
//# sourceMappingURL=TableHandlesController.js.map