const cssVariablesHelper = (theme, editorDOM, unset = false) => {
    const result = [];
    function traverse(current, currentKey = "--bn") {
        for (const key in current) {
            const kebabCaseKey = key
                .replace(/([a-z])([A-Z])/g, "$1-$2")
                .toLowerCase();
            const fullKey = `${currentKey}-${kebabCaseKey}`;
            if (typeof current[key] !== "object") {
                // Convert numbers to px
                if (typeof current[key] === "number") {
                    current[key] = `${current[key]}px`;
                }
                if (unset) {
                    editorDOM.style.removeProperty(fullKey);
                }
                else {
                    editorDOM.style.setProperty(fullKey, current[key].toString());
                }
            }
            else {
                traverse(current[key], fullKey);
            }
        }
    }
    traverse(theme);
    return result;
};
export const applyBlockNoteCSSVariablesFromTheme = (theme, editorDOM) => cssVariablesHelper(theme, editorDOM);
// We don't need a theme to remove the CSS variables, but having access to a
// theme object allows us to use the same logic to set/unset them, so this
// placeholder theme is used.
const placeholderTheme = {
    colors: {
        editor: {
            text: undefined,
            background: undefined,
        },
        menu: {
            text: undefined,
            background: undefined,
        },
        tooltip: {
            text: undefined,
            background: undefined,
        },
        hovered: {
            text: undefined,
            background: undefined,
        },
        selected: {
            text: undefined,
            background: undefined,
        },
        disabled: {
            text: undefined,
            background: undefined,
        },
        shadow: undefined,
        border: undefined,
        sideMenu: undefined,
        highlights: {
            gray: {
                text: undefined,
                background: undefined,
            },
            brown: {
                text: undefined,
                background: undefined,
            },
            red: {
                text: undefined,
                background: undefined,
            },
            orange: {
                text: undefined,
                background: undefined,
            },
            yellow: {
                text: undefined,
                background: undefined,
            },
            green: {
                text: undefined,
                background: undefined,
            },
            blue: {
                text: undefined,
                background: undefined,
            },
            purple: {
                text: undefined,
                background: undefined,
            },
            pink: {
                text: undefined,
                background: undefined,
            },
        },
    },
    borderRadius: undefined,
    fontFamily: undefined,
};
export const removeBlockNoteCSSVariables = (editorDOM) => cssVariablesHelper(placeholderTheme, editorDOM, true);
//# sourceMappingURL=BlockNoteTheme.js.map