import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { mergeCSSClasses, } from "@blocknote/core";
import { MantineProvider } from "@mantine/core";
import React, { useCallback, useEffect, useMemo, useState, } from "react";
import usePrefersColorScheme from "use-prefers-color-scheme";
import { useEditorChange } from "../hooks/useEditorChange";
import { useEditorSelectionChange } from "../hooks/useEditorSelectionChange";
import { mergeRefs } from "../util/mergeRefs";
import { BlockNoteContext, useBlockNoteContext } from "./BlockNoteContext";
import { BlockNoteDefaultUI, } from "./BlockNoteDefaultUI";
import { applyBlockNoteCSSVariablesFromTheme, removeBlockNoteCSSVariables, } from "./BlockNoteTheme";
import { EditorContent } from "./EditorContent";
import "./styles.css";
const mantineTheme = {
    // Removes button press effect
    activeClassName: "",
};
const emptyFn = () => {
    // noop
};
function BlockNoteViewComponent(props, ref) {
    const { editor, className, theme, children, editable, onSelectionChange, onChange, formattingToolbar, linkToolbar, slashMenu, sideMenu, imageToolbar, tableHandles, ...rest } = props;
    const existingContext = useBlockNoteContext();
    const systemColorScheme = usePrefersColorScheme();
    const defaultColorScheme = existingContext?.colorSchemePreference || systemColorScheme;
    const [editorColorScheme, setEditorColorScheme] = useState(undefined);
    const containerRef = useCallback((node) => {
        if (!node) {
            // todo: clean variables?
            return;
        }
        removeBlockNoteCSSVariables(node);
        if (theme === "light") {
            setEditorColorScheme("light");
            return;
        }
        if (theme === "dark") {
            setEditorColorScheme("dark");
            return;
        }
        if (typeof theme === "object") {
            if ("light" in theme && "dark" in theme) {
                applyBlockNoteCSSVariablesFromTheme(theme[defaultColorScheme === "dark" ? "dark" : "light"], node);
                setEditorColorScheme(defaultColorScheme === "dark" ? "dark" : "light");
                return;
            }
            applyBlockNoteCSSVariablesFromTheme(theme, node);
            setEditorColorScheme(undefined);
            return;
        }
        setEditorColorScheme(defaultColorScheme === "dark" ? "dark" : "light");
    }, [defaultColorScheme, theme]);
    useEditorChange(onChange || emptyFn, editor);
    useEditorSelectionChange(onSelectionChange || emptyFn, editor);
    useEffect(() => {
        editor.isEditable = editable !== false;
    }, [editable, editor]);
    const renderChildren = useMemo(() => {
        return (_jsxs(_Fragment, { children: [children, _jsx(BlockNoteDefaultUI, { formattingToolbar: formattingToolbar, linkToolbar: linkToolbar, slashMenu: slashMenu, sideMenu: sideMenu, imageToolbar: imageToolbar, tableHandles: tableHandles })] }));
    }, [
        children,
        formattingToolbar,
        linkToolbar,
        imageToolbar,
        sideMenu,
        slashMenu,
        tableHandles,
    ]);
    const context = useMemo(() => {
        return {
            ...existingContext,
            editor,
        };
    }, [existingContext, editor]);
    const refs = useMemo(() => {
        return mergeRefs([containerRef, editor._tiptapEditor.mount, ref]);
    }, [containerRef, editor._tiptapEditor.mount, ref]);
    return (
    // `cssVariablesSelector` scopes Mantine CSS variables to only the editor,
    // as proposed here:  https://github.com/orgs/mantinedev/discussions/5685
    _jsx(MantineProvider, { theme: mantineTheme, cssVariablesSelector: ".bn-container", children: _jsx(BlockNoteContext.Provider, { value: context, children: _jsx(EditorContent, { editor: editor, children: _jsx("div", { className: mergeCSSClasses("bn-container", className || ""), "data-color-scheme": editorColorScheme, ...rest, ref: refs, children: renderChildren }) }) }) }));
}
export const BlockNoteView = React.forwardRef(BlockNoteViewComponent); // need hack to get types working with generics
//# sourceMappingURL=BlockNoteView.js.map