import { useState } from "react";
import { useBlockNoteContext } from "../editor/BlockNoteContext";
import { useEditorChange } from "./useEditorChange";
import { useEditorSelectionChange } from "./useEditorSelectionChange";
export function useActiveStyles(editor) {
    const editorContext = useBlockNoteContext();
    if (!editor) {
        editor = editorContext?.editor;
    }
    if (!editor) {
        throw new Error("'editor' is required, either from BlockNoteContext or as a function argument");
    }
    const e = editor;
    const [styles, setStyles] = useState(() => e.getActiveStyles());
    // Updates state on editor content change.
    useEditorChange(() => {
        setStyles(e.getActiveStyles());
    }, e);
    // Updates state on selection change.
    useEditorSelectionChange(() => {
        setStyles(e.getActiveStyles());
    }, e);
    return styles;
}
//# sourceMappingURL=useActiveStyles.js.map