import { useFloating, useTransitionStyles, } from "@floating-ui/react";
import { useEffect, useMemo } from "react";
export function useUIElementPositioning(show, referencePos, zIndex, options) {
    const { refs, update, context, floatingStyles } = useFloating({
        open: show,
        ...options,
    });
    const { isMounted, styles } = useTransitionStyles(context);
    useEffect(() => {
        update();
    }, [referencePos, update]);
    useEffect(() => {
        // Will be null on initial render when used in UI component controllers.
        if (referencePos === null) {
            return;
        }
        refs.setReference({
            getBoundingClientRect: () => referencePos,
        });
    }, [referencePos, refs]);
    return useMemo(() => ({
        isMounted,
        ref: refs.setFloating,
        style: {
            display: "flex",
            ...styles,
            ...floatingStyles,
            zIndex: zIndex,
        },
    }), [floatingStyles, isMounted, refs.setFloating, styles, zIndex]);
}
//# sourceMappingURL=useUIElementPositioning.js.map