import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useContext } from "react";
import { BlockNoteEditor, BlockNoteSchema, defaultBlockSpecs, defaultProps, uploadToTmpFilesDotOrg_DEV_ONLY, } from "@blocknote/core";
import { createReactBlockSpec } from "../../schema/ReactBlockSpec";
const ReactCustomParagraph = createReactBlockSpec({
    type: "reactCustomParagraph",
    propSchema: defaultProps,
    content: "inline",
}, {
    render: (props) => (_jsx("p", { ref: props.contentRef, className: "react-custom-paragraph" })),
    toExternalHTML: () => (_jsx("p", { className: "react-custom-paragraph", children: "Hello World" })),
});
const SimpleReactCustomParagraph = createReactBlockSpec({
    type: "simpleReactCustomParagraph",
    propSchema: defaultProps,
    content: "inline",
}, {
    render: (props) => (_jsx("p", { ref: props.contentRef, className: "simple-react-custom-paragraph" })),
});
export const TestContext = createContext(undefined);
const ReactContextParagraphComponent = (props) => {
    const testData = useContext(TestContext);
    if (testData === undefined) {
        throw Error();
    }
    return _jsx("div", { ref: props.contentRef });
};
const ReactContextParagraph = createReactBlockSpec({
    type: "reactContextParagraph",
    propSchema: defaultProps,
    content: "inline",
}, {
    render: ReactContextParagraphComponent,
});
const schema = BlockNoteSchema.create({
    blockSpecs: {
        ...defaultBlockSpecs,
        reactCustomParagraph: ReactCustomParagraph,
        simpleReactCustomParagraph: SimpleReactCustomParagraph,
        reactContextParagraph: ReactContextParagraph,
    },
});
export const customReactBlockSchemaTestCases = {
    name: "custom react block schema",
    createEditor: () => {
        return BlockNoteEditor.create({
            schema,
            uploadFile: uploadToTmpFilesDotOrg_DEV_ONLY,
        });
    },
    documents: [
        {
            name: "reactCustomParagraph/basic",
            blocks: [
                {
                    type: "reactCustomParagraph",
                    content: "React Custom Paragraph",
                },
            ],
        },
        {
            name: "reactCustomParagraph/styled",
            blocks: [
                {
                    type: "reactCustomParagraph",
                    props: {
                        textAlignment: "center",
                        textColor: "orange",
                        backgroundColor: "pink",
                    },
                    content: [
                        {
                            type: "text",
                            styles: {},
                            text: "Plain ",
                        },
                        {
                            type: "text",
                            styles: {
                                textColor: "red",
                            },
                            text: "Red Text ",
                        },
                        {
                            type: "text",
                            styles: {
                                backgroundColor: "blue",
                            },
                            text: "Blue Background ",
                        },
                        {
                            type: "text",
                            styles: {
                                textColor: "red",
                                backgroundColor: "blue",
                            },
                            text: "Mixed Colors",
                        },
                    ],
                },
            ],
        },
        {
            name: "reactCustomParagraph/nested",
            blocks: [
                {
                    type: "reactCustomParagraph",
                    content: "React Custom Paragraph",
                    children: [
                        {
                            type: "reactCustomParagraph",
                            content: "Nested React Custom Paragraph 1",
                        },
                        {
                            type: "reactCustomParagraph",
                            content: "Nested React Custom Paragraph 2",
                        },
                    ],
                },
            ],
        },
        {
            name: "simpleReactCustomParagraph/basic",
            blocks: [
                {
                    type: "simpleReactCustomParagraph",
                    content: "React Custom Paragraph",
                },
            ],
        },
        {
            name: "simpleReactCustomParagraph/styled",
            blocks: [
                {
                    type: "simpleReactCustomParagraph",
                    props: {
                        textAlignment: "center",
                        textColor: "orange",
                        backgroundColor: "pink",
                    },
                    content: [
                        {
                            type: "text",
                            styles: {},
                            text: "Plain ",
                        },
                        {
                            type: "text",
                            styles: {
                                textColor: "red",
                            },
                            text: "Red Text ",
                        },
                        {
                            type: "text",
                            styles: {
                                backgroundColor: "blue",
                            },
                            text: "Blue Background ",
                        },
                        {
                            type: "text",
                            styles: {
                                textColor: "red",
                                backgroundColor: "blue",
                            },
                            text: "Mixed Colors",
                        },
                    ],
                },
            ],
        },
        {
            name: "simpleReactCustomParagraph/nested",
            blocks: [
                {
                    type: "simpleReactCustomParagraph",
                    content: "Custom React Paragraph",
                    children: [
                        {
                            type: "simpleReactCustomParagraph",
                            content: "Nested React Custom Paragraph 1",
                        },
                        {
                            type: "simpleReactCustomParagraph",
                            content: "Nested React Custom Paragraph 2",
                        },
                    ],
                },
            ],
        },
        {
            name: "reactContextParagraph/basic",
            blocks: [
                {
                    type: "reactContextParagraph",
                    content: "React Context Paragraph",
                },
            ],
        },
    ],
};
//# sourceMappingURL=customReactBlocks.js.map